/*********************************************************************
 * File:   tty.c  (part of TTYTALK)
 * Author: Victor Volkman
 * Date:   June, 1988
 *
 * The program consists of these files:
 *   tty.c queue.c install.c serial.c ttycmds.c filter.c ttyio.c
 *   int4.asm
 *   tty.h ttycmds.h ttyfunc.h serial.h queue.h
 *
 * Default compile is for Lattice C.  Compile with command line like
 *     ls -ms -n -v
 *
 * Verified for Microsoft C.  Compile with command lines of the form
 *     qcl /c /DMSC /Gs file.c
 * & assemble the .asm module with
 *     masm /MX /DMSC int4;
 *
 * Link Instructions:
 *  Create the file tty.lnk as
 *    tty queue install serial ttycmds filter ttyio int4
 *    tty.exe /NOI /CO
 *    (blank line)
 *    (blank line)
 *
 *  (note that this file has two blank lines at the end)
 *  Then link with "link @tty.lnk".
 ********************************************************************/
#include "tty.h"

#if defined MSC     /* Define this for Microsoft */
#include <signal.h>
#endif

extern int r_errs, q_errs;
extern int iobase;

FILE *send_file;
FILE *capture_file;
int adapter = COM1;
int c_row, c_col;    /* cursor coordinates (row,col) */
int capture_mode=FALSE;
enum cmdtype mode;   /* tty current mode */

int main(argc,argv)
int argc;
char **argv;
{
    int c, done;

    mode = CMD_NONE;
    vid_scroll(0,0,24,79,0);
    mk_queue();         /* allocate and init. queue */
    disp_cmdline();
    vid_setrc(1,1);

    read_cfg("std.cfg");   /* read configuration files */
    start_rcv();
    if (argc > 1) read_cfg(argv[1]);

    done = FALSE;
    c_row = 0;
    c_col = 0;

    while (mode != CMD_QUIT) {
        if (chk_queue()!=0) {   /* incoming characters? */
            c = dequeue();
            xlat_char_in(c);
        }
        else if (kbhit()!=0)    /* keyboard input? */
            kbd_cmd();
        else if (mode==CMD_SEND && chk_xmt())  /* file output? */
            send_file_char();
    }

    stop_rcv();
    vid_scroll(0,0,24,79,0);
    printf("%d receive errors\n %d buffer overflows\n",r_errs,q_errs);
    if (capture_mode)
        fclose(capture_file);

    return r_errs || q_errs;
}



void trim_cr(str)  /* scan for and remove CRs and LFs */
char *str;
{
    char *temp;

    for (temp=str; *temp!='\0'; temp++) {
        if (*temp==0x0D || *temp==0x0A)
            *temp = '\0';
        if (isspace(*temp)) /** convert tabs to blanks */
            *temp = ' ';
    }
}
